'use strict';

function _toArray(arr) { return Array.isArray(arr) ? arr : Array.from(arr); }

var path = require('path');
var spawn = require('cross-spawn');

var _require = require('../utils'),
    resolveBin = _require.resolveBin,
    hasFile = _require.hasFile,
    hasPkgProp = _require.hasPkgProp,
    getPackageManagerBin = _require.getPackageManagerBin;

var here = function (p) {
  return path.join(__dirname, p);
};
var hereRelative = function (p) {
  return here(p).replace(process.cwd(), '.');
};

var _process$argv = _toArray(process.argv),
    args = _process$argv.slice(2);

var useBuiltinConfig = !args.includes('--config') && !hasFile('.lintstagedrc') && !hasFile('lintstaged.config.js') && !hasPkgProp('lintstaged');

var config = useBuiltinConfig ? ['--config', hereRelative('../config/lintstagedrc.js')] : [];

var lintStagedResult = spawn.sync(resolveBin('lint-staged'), [].concat(config), {
  stdio: 'inherit'
});

if (lintStagedResult.status !== 0) {
  process.exit(lintStagedResult.status);
} else {
  var validateResult = spawn.sync(getPackageManagerBin(), ['run', 'validate'], {
    stdio: 'inherit'
  });

  process.exit(validateResult.status);
}