'use strict';

var spawn = require('cross-spawn');

var _require = require('../utils'),
    parseEnv = _require.parseEnv,
    resolveBin = _require.resolveBin,
    ifScript = _require.ifScript,
    getConcurrentlyArgs = _require.getConcurrentlyArgs,
    getPackageManagerBin = _require.getPackageManagerBin;

// precommit runs linting and tests on the relevant files
// so those scripts don't need to be run if we're running
// this in the context of a precommit hook.


var precommit = parseEnv('SCRIPTS_PRECOMMIT', false);
var validateScripts = process.argv[2];
var useDefaultScripts = typeof validateScripts !== 'string';

var pm = getPackageManagerBin();
var extraDashDash = pm === 'npm' ? '-- ' : '';

var scripts = useDefaultScripts ? {
  build: ifScript('build', `${getPackageManagerBin()} run build --silent`),
  lint: precommit ? null : ifScript('lint', `${getPackageManagerBin()} run lint --quiet`),
  test: precommit ? null : ifScript('test', `${getPackageManagerBin()} run test --silent ${extraDashDash}--coverage`),
  flow: ifScript('flow', `${getPackageManagerBin()} run flow --silent`)
} : validateScripts.split(',').reduce(function (scriptsToRun, name) {
  return Object.assign({}, scriptsToRun, {
    [name]: `${getPackageManagerBin()} run ${name} --silent`
  });
}, {});

var result = spawn.sync(resolveBin('concurrently'), getConcurrentlyArgs(scripts), { stdio: 'inherit' });

process.exit(result.status);